__all__ = [
    '__title__',
    '__summary__',
    '__uri__',
    '__version__',
    '__author__',
    '__email__',
    '__license__',
    '__copyright__'
]

__title__ = 'bozor'
__summary__ = 'A higher level package to retrieve details on AWS items.'
__uri__ = 'https://github.com/monkeysecurity/bozor'

__version__ = '0.0.1dev0'

__author__ = 'Patrick Kelley'
__email__ = 'patrick@netflix.com'

__license__ = 'Apache License, Version 2.0'
__copyright__ = 'Copyright 2016 %s' % __author__
